diff --git a/windows/ss.iss b/windows/ss.iss
index a19bb13..d9b91f2 100644
--- a/windows/ss.iss
+++ b/windows/ss.iss
@@ -7,12 +7,12 @@
; (To generate a new GUID, click Tools | Generate GUID inside the IDE.)
AppId={{6F127615-6AD4-4BD7-8135-2444A335B5CD}
AppName=Relational
-AppVerName=Relational ver. 0.12
+AppVerName=Relational ver. 1.1
AppPublisher=Salvo 'LtWorf' Tomaselli
AppPublisherURL=http://galileo.dmi.unict.it/wiki/relational/
AppSupportURL=http://galileo.dmi.unict.it/wiki/relational/
AppUpdatesURL=http://galileo.dmi.unict.it/wiki/relational/
-DefaultDirName={pf}\Relational 0.12
+DefaultDirName={pf}\Relational 1.1
DefaultGroupName=Relational
AllowNoIcons=yes
LicenseFile=COPYING
diff --git a/windows/input.py b/windows/input.py
index 1a3c552..df58f96 100644
--- a/windows/input.py
+++ b/windows/input.py
@@ -1,30 +1,41 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# coding=UTF-8
-# Relational
-# Copyright (C) 2008 Salvo "LtWorf" Tomaselli
-#
-# Relational is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program. If not, see .
-#
-# author Salvo "LtWorf" Tomaselli
-
-from distutils.core import setup
-import py2exe
-setup(windows=
- [
- {"script": "relational_gui.py","icon_resources": [(0, "windows/favicon.ico")]}
- ]
- ,name="Relational",
- version="0.12"
- )
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+# coding=UTF-8
+# Relational
+# Copyright (C) 2008 Salvo "LtWorf" Tomaselli
+#
+# Relational is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see .
+#
+# author Salvo "LtWorf" Tomaselli
+
+from distutils.core import setup
+import py2exe
+
+#It was complaining about the already installed MSVCP90.dll
+#So it is removed from the checks and signals to the user the
+#probable need to manually install it. Since to redistribute it
+#some dammit certificates are needed.
+
+setup(options = {
+ "py2exe": {
+ "dll_excludes": ["MSVCP90.dll"]
+ }
+ },
+ windows=
+ [
+ {"script": "relational_gui.py","icon_resources": [(0, "windows/favicon.ico")]}
+ ]
+ ,name="Relational",
+ version="1.1"
+ )